pub struct CollectionInfo {
pub id: u64,
pub name: String,
pub poster_path: Option<String>,
pub backdrop_path: Option<String>,
}Fields
id: u64name: Stringposter_path: Option<String>backdrop_path: Option<String>Trait Implementations
Sourceimpl Archive for CollectionInfo
impl Archive for CollectionInfo
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedCollectionInfo
type Archived = ArchivedCollectionInfo
The archived representation of this type. Read more
Sourcetype Resolver = CollectionInfoResolver
type Resolver = CollectionInfoResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for CollectionInfo
impl Clone for CollectionInfo
Sourcefn clone(&self) -> CollectionInfo
fn clone(&self) -> CollectionInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CollectionInfo
impl Debug for CollectionInfo
Sourceimpl Default for CollectionInfo
impl Default for CollectionInfo
Sourcefn default() -> CollectionInfo
fn default() -> CollectionInfo
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CollectionInfo
impl<'de> Deserialize<'de> for CollectionInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<CollectionInfo, __D> for Archived<CollectionInfo>
impl<__D: Fallible + ?Sized> Deserialize<CollectionInfo, __D> for Archived<CollectionInfo>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<CollectionInfo, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<CollectionInfo, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for CollectionInfo
impl PartialEq for CollectionInfo
Sourceimpl Serialize for CollectionInfo
impl Serialize for CollectionInfo
impl StructuralPartialEq for CollectionInfo