pub struct ContentRating {
pub iso_3166_1: String,
pub rating: Option<String>,
pub rating_system: Option<String>,
pub descriptors: Vec<String>,
}Fields
iso_3166_1: Stringrating: Option<String>rating_system: Option<String>descriptors: Vec<String>Trait Implementations
Sourceimpl Archive for ContentRating
impl Archive for ContentRating
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedContentRating
type Archived = ArchivedContentRating
The archived representation of this type. Read more
Sourcetype Resolver = ContentRatingResolver
type Resolver = ContentRatingResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for ContentRating
impl Clone for ContentRating
Sourcefn clone(&self) -> ContentRating
fn clone(&self) -> ContentRating
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContentRating
impl Debug for ContentRating
Sourceimpl Default for ContentRating
impl Default for ContentRating
Sourcefn default() -> ContentRating
fn default() -> ContentRating
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ContentRating
impl<'de> Deserialize<'de> for ContentRating
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ContentRating, __D> for Archived<ContentRating>
impl<__D: Fallible + ?Sized> Deserialize<ContentRating, __D> for Archived<ContentRating>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ContentRating, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ContentRating, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for ContentRating
impl PartialEq for ContentRating
Sourceimpl Serialize for ContentRating
impl Serialize for ContentRating
impl StructuralPartialEq for ContentRating