pub struct EpisodeGroupMembership {
pub id: String,
pub name: String,
pub description: Option<String>,
pub group_type: Option<String>,
}Fields
id: Stringname: Stringdescription: Option<String>group_type: Option<String>Trait Implementations
Sourceimpl Archive for EpisodeGroupMembership
impl Archive for EpisodeGroupMembership
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedEpisodeGroupMembership
type Archived = ArchivedEpisodeGroupMembership
The archived representation of this type. Read more
Sourcetype Resolver = EpisodeGroupMembershipResolver
type Resolver = EpisodeGroupMembershipResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for EpisodeGroupMembership
impl Clone for EpisodeGroupMembership
Sourcefn clone(&self) -> EpisodeGroupMembership
fn clone(&self) -> EpisodeGroupMembership
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EpisodeGroupMembership
impl Debug for EpisodeGroupMembership
Sourceimpl<'de> Deserialize<'de> for EpisodeGroupMembership
impl<'de> Deserialize<'de> for EpisodeGroupMembership
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<EpisodeGroupMembership, __D> for Archived<EpisodeGroupMembership>
impl<__D: Fallible + ?Sized> Deserialize<EpisodeGroupMembership, __D> for Archived<EpisodeGroupMembership>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<EpisodeGroupMembership, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<EpisodeGroupMembership, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for EpisodeGroupMembership
impl PartialEq for EpisodeGroupMembership
Sourceimpl Serialize for EpisodeGroupMembership
impl Serialize for EpisodeGroupMembership
impl StructuralPartialEq for EpisodeGroupMembership