pub struct LibraryReference {
pub id: LibraryId,
pub name: String,
pub library_type: LibraryType,
pub paths: Vec<PathBuf>,
}Fields
id: LibraryIdname: Stringlibrary_type: LibraryTypepaths: Vec<PathBuf>Trait Implementations
Sourceimpl Archive for LibraryReferencewhere
LibraryId: Archive,
String: Archive,
LibraryType: Archive,
VecPathBuf: ArchiveWith<Vec<PathBuf>>,
impl Archive for LibraryReferencewhere
LibraryId: Archive,
String: Archive,
LibraryType: Archive,
VecPathBuf: ArchiveWith<Vec<PathBuf>>,
Sourcetype Archived = ArchivedLibraryReference
type Archived = ArchivedLibraryReference
The archived representation of this type. Read more
Sourcetype Resolver = LibraryReferenceResolver
type Resolver = LibraryReferenceResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
fn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
Creates the archived version of this value at the given position and
writes it to the given output. Read more
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourceimpl Clone for LibraryReference
impl Clone for LibraryReference
Sourcefn clone(&self) -> LibraryReference
fn clone(&self) -> LibraryReference
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LibraryReference
impl Debug for LibraryReference
Sourceimpl<'de> Deserialize<'de> for LibraryReference
impl<'de> Deserialize<'de> for LibraryReference
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<LibraryReference, __D> for Archived<LibraryReference>where
LibraryId: Archive,
<LibraryId as Archive>::Archived: Deserialize<LibraryId, __D>,
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
LibraryType: Archive,
<LibraryType as Archive>::Archived: Deserialize<LibraryType, __D>,
VecPathBuf: ArchiveWith<Vec<PathBuf>> + DeserializeWith<<VecPathBuf as ArchiveWith<Vec<PathBuf>>>::Archived, Vec<PathBuf>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<LibraryReference, __D> for Archived<LibraryReference>where
LibraryId: Archive,
<LibraryId as Archive>::Archived: Deserialize<LibraryId, __D>,
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
LibraryType: Archive,
<LibraryType as Archive>::Archived: Deserialize<LibraryType, __D>,
VecPathBuf: ArchiveWith<Vec<PathBuf>> + DeserializeWith<<VecPathBuf as ArchiveWith<Vec<PathBuf>>>::Archived, Vec<PathBuf>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<LibraryReference, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<LibraryReference, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for LibraryReferencewhere
LibraryId: Serialize<__S>,
String: Serialize<__S>,
LibraryType: Serialize<__S>,
VecPathBuf: SerializeWith<Vec<PathBuf>, __S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for LibraryReferencewhere
LibraryId: Serialize<__S>,
String: Serialize<__S>,
LibraryType: Serialize<__S>,
VecPathBuf: SerializeWith<Vec<PathBuf>, __S>,