pub struct PersonExternalIds {
pub imdb_id: Option<String>,
pub facebook_id: Option<String>,
pub instagram_id: Option<String>,
pub twitter_id: Option<String>,
pub wikidata_id: Option<String>,
pub tiktok_id: Option<String>,
pub youtube_id: Option<String>,
}Fields
imdb_id: Option<String>facebook_id: Option<String>instagram_id: Option<String>twitter_id: Option<String>wikidata_id: Option<String>tiktok_id: Option<String>youtube_id: Option<String>Trait Implementations
Sourceimpl Archive for PersonExternalIds
impl Archive for PersonExternalIds
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedPersonExternalIds
type Archived = ArchivedPersonExternalIds
The archived representation of this type. Read more
Sourcetype Resolver = PersonExternalIdsResolver
type Resolver = PersonExternalIdsResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for PersonExternalIds
impl Clone for PersonExternalIds
Sourcefn clone(&self) -> PersonExternalIds
fn clone(&self) -> PersonExternalIds
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PersonExternalIds
impl Debug for PersonExternalIds
Sourceimpl Default for PersonExternalIds
impl Default for PersonExternalIds
Sourcefn default() -> PersonExternalIds
fn default() -> PersonExternalIds
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PersonExternalIds
impl<'de> Deserialize<'de> for PersonExternalIds
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<PersonExternalIds, __D> for Archived<PersonExternalIds>
impl<__D: Fallible + ?Sized> Deserialize<PersonExternalIds, __D> for Archived<PersonExternalIds>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<PersonExternalIds, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<PersonExternalIds, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl Hash for PersonExternalIds
impl Hash for PersonExternalIds
Sourceimpl PartialEq for PersonExternalIds
impl PartialEq for PersonExternalIds
Sourceimpl Serialize for PersonExternalIds
impl Serialize for PersonExternalIds
impl Eq for PersonExternalIds
impl StructuralPartialEq for PersonExternalIds