pub struct RelatedMediaRef {
pub tmdb_id: u64,
pub title: Option<String>,
}Fields
tmdb_id: u64title: Option<String>Trait Implementations
Sourceimpl Archive for RelatedMediaRef
impl Archive for RelatedMediaRef
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedRelatedMediaRef
type Archived = ArchivedRelatedMediaRef
The archived representation of this type. Read more
Sourcetype Resolver = RelatedMediaRefResolver
type Resolver = RelatedMediaRefResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for RelatedMediaRef
impl Clone for RelatedMediaRef
Sourcefn clone(&self) -> RelatedMediaRef
fn clone(&self) -> RelatedMediaRef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RelatedMediaRef
impl Debug for RelatedMediaRef
Sourceimpl<'de> Deserialize<'de> for RelatedMediaRef
impl<'de> Deserialize<'de> for RelatedMediaRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<RelatedMediaRef, __D> for Archived<RelatedMediaRef>
impl<__D: Fallible + ?Sized> Deserialize<RelatedMediaRef, __D> for Archived<RelatedMediaRef>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<RelatedMediaRef, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<RelatedMediaRef, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for RelatedMediaRef
impl PartialEq for RelatedMediaRef
Sourceimpl Serialize for RelatedMediaRef
impl Serialize for RelatedMediaRef
impl StructuralPartialEq for RelatedMediaRef