pub struct Translation {
pub iso_3166_1: String,
pub iso_639_1: String,
pub name: Option<String>,
pub english_name: Option<String>,
pub title: Option<String>,
pub overview: Option<String>,
pub homepage: Option<String>,
pub tagline: Option<String>,
}Fields
iso_3166_1: Stringiso_639_1: Stringname: Option<String>english_name: Option<String>title: Option<String>overview: Option<String>homepage: Option<String>tagline: Option<String>Trait Implementations
Sourceimpl Archive for Translation
impl Archive for Translation
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedTranslation
type Archived = ArchivedTranslation
The archived representation of this type. Read more
Sourcetype Resolver = TranslationResolver
type Resolver = TranslationResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for Translation
impl Clone for Translation
Sourcefn clone(&self) -> Translation
fn clone(&self) -> Translation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Translation
impl Debug for Translation
Sourceimpl Default for Translation
impl Default for Translation
Sourcefn default() -> Translation
fn default() -> Translation
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for Translation
impl<'de> Deserialize<'de> for Translation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<Translation, __D> for Archived<Translation>
impl<__D: Fallible + ?Sized> Deserialize<Translation, __D> for Archived<Translation>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<Translation, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<Translation, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for Translation
impl PartialEq for Translation
Sourceimpl Serialize for Translation
impl Serialize for Translation
impl StructuralPartialEq for Translation