pub struct Video {
pub key: String,
pub name: Option<String>,
pub site: String,
pub video_type: Option<String>,
pub official: Option<bool>,
pub iso_639_1: Option<String>,
pub iso_3166_1: Option<String>,
pub published_at: Option<String>,
pub size: Option<u32>,
}Fields
key: Stringname: Option<String>site: Stringvideo_type: Option<String>official: Option<bool>iso_639_1: Option<String>iso_3166_1: Option<String>published_at: Option<String>size: Option<u32>Trait Implementations
Sourceimpl Archive for Video
impl Archive for Video
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedVideo
type Archived = ArchivedVideo
The archived representation of this type. Read more
Sourcetype Resolver = VideoResolver
type Resolver = VideoResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl<'de> Deserialize<'de> for Video
impl<'de> Deserialize<'de> for Video
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<Video, __D> for Archived<Video>where
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
Option<bool>: Archive,
<Option<bool> as Archive>::Archived: Deserialize<Option<bool>, __D>,
Option<u32>: Archive,
<Option<u32> as Archive>::Archived: Deserialize<Option<u32>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<Video, __D> for Archived<Video>where
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
Option<bool>: Archive,
<Option<bool> as Archive>::Archived: Deserialize<Option<bool>, __D>,
Option<u32>: Archive,
<Option<u32> as Archive>::Archived: Deserialize<Option<u32>, __D>,
impl StructuralPartialEq for Video