pub struct ImageWithMetadata {
pub endpoint: String,
pub metadata: ImageMetadata,
}Fields
endpoint: Stringmetadata: ImageMetadataTrait Implementations
Sourceimpl Archive for ImageWithMetadata
impl Archive for ImageWithMetadata
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedImageWithMetadata
type Archived = ArchivedImageWithMetadata
The archived representation of this type. Read more
Sourcetype Resolver = ImageWithMetadataResolver
type Resolver = ImageWithMetadataResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for ImageWithMetadata
impl Clone for ImageWithMetadata
Sourcefn clone(&self) -> ImageWithMetadata
fn clone(&self) -> ImageWithMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImageWithMetadata
impl Debug for ImageWithMetadata
Sourceimpl<'de> Deserialize<'de> for ImageWithMetadata
impl<'de> Deserialize<'de> for ImageWithMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ImageWithMetadata, __D> for Archived<ImageWithMetadata>where
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
ImageMetadata: Archive,
<ImageMetadata as Archive>::Archived: Deserialize<ImageMetadata, __D>,
impl<__D: Fallible + ?Sized> Deserialize<ImageWithMetadata, __D> for Archived<ImageWithMetadata>where
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
ImageMetadata: Archive,
<ImageMetadata as Archive>::Archived: Deserialize<ImageMetadata, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ImageWithMetadata, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ImageWithMetadata, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for ImageWithMetadata
impl PartialEq for ImageWithMetadata
Sourceimpl Serialize for ImageWithMetadata
impl Serialize for ImageWithMetadata
impl StructuralPartialEq for ImageWithMetadata