pub enum ImageSize {
Poster(PosterSize),
Backdrop(BackdropSize),
Thumbnail(EpisodeSize),
Profile(ProfileSize),
}Expand description
Image size variants
Variants
Implementations
Sourceimpl ImageSize
impl ImageSize
Sourcepub const fn poster_large() -> Self
pub const fn poster_large() -> Self
Large poster size (780px)
Sourcepub fn to_nearest_tmdb_size(self, original_width: ImageSize) -> Self
pub fn to_nearest_tmdb_size(self, original_width: ImageSize) -> Self
Rounds up to the nearest tmdb api valid size variant, always returns with a specific width
pub const fn original(width: u32, image_variant: ImageVariant) -> Self
pub const fn original_unknown(image_variant: ImageVariant) -> Self
pub const fn is_original(self) -> bool
pub const fn custom(width: u32, image_variant: ImageVariant) -> Self
pub const fn is_resized(self) -> bool
pub fn from_size_and_variant(width: u32, variant: ImageVariant) -> Self
pub fn sqlx_image_size_variant(self) -> SqlxImageSizeVariant
pub fn dimensions(&self) -> Option<(u32, u32)>
Sourcepub fn dimensions_unchecked(&self) -> (u32, u32)
pub fn dimensions_unchecked(&self) -> (u32, u32)
Panics if given an Original variant with no width included
pub fn has_width(&self) -> bool
pub fn image_variant(&self) -> ImageVariant
pub fn image_variant_str(&self) -> &'static str
pub fn image_variant_str_path(&self) -> &'static str
Sourcepub fn to_tmdb_param(&self) -> &'static str
pub fn to_tmdb_param(&self) -> &'static str
Convert to URL string size
Sourcepub const fn width_unchecked(&self) -> u32
pub const fn width_unchecked(&self) -> u32
Get the width for this size Panics if given an Original variant with no width included
pub fn width_name(&self) -> String
pub fn width_name_str(&self) -> &'static str