pub struct Library {Show 15 fields
pub id: LibraryId,
pub name: String,
pub library_type: LibraryType,
pub paths: Vec<PathBuf>,
pub scan_interval_minutes: u32,
pub last_scan: Option<DateTime<Utc>>,
pub enabled: bool,
pub auto_scan: bool,
pub watch_for_changes: bool,
pub analyze_on_scan: bool,
pub max_retry_attempts: u32,
pub movie_ref_batch_size: MovieReferenceBatchSize,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
pub media: Option<Vec<Media>>,
}Expand description
Represents a media library with a specific type
Fields
id: LibraryIdname: Stringlibrary_type: LibraryTypepaths: Vec<PathBuf>scan_interval_minutes: u32last_scan: Option<DateTime<Utc>>enabled: boolauto_scan: boolwatch_for_changes: boolanalyze_on_scan: boolmax_retry_attempts: u32movie_ref_batch_size: MovieReferenceBatchSizecreated_at: DateTime<Utc>updated_at: DateTime<Utc>media: Option<Vec<Media>>Trait Implementations
Sourceimpl Archive for Librarywhere
LibraryId: Archive,
String: Archive,
LibraryType: Archive,
VecPathBuf: ArchiveWith<Vec<PathBuf>>,
u32: Archive,
OptionDateTime: ArchiveWith<Option<DateTime<Utc>>>,
bool: Archive,
MovieReferenceBatchSize: Archive,
DateTimeWrapper: ArchiveWith<DateTime<Utc>>,
Option<Vec<Media>>: Archive,
impl Archive for Librarywhere
LibraryId: Archive,
String: Archive,
LibraryType: Archive,
VecPathBuf: ArchiveWith<Vec<PathBuf>>,
u32: Archive,
OptionDateTime: ArchiveWith<Option<DateTime<Utc>>>,
bool: Archive,
MovieReferenceBatchSize: Archive,
DateTimeWrapper: ArchiveWith<DateTime<Utc>>,
Option<Vec<Media>>: Archive,
Sourcetype Archived = ArchivedLibrary
type Archived = ArchivedLibrary
The archived representation of this type. Read more
Sourcetype Resolver = LibraryResolver
type Resolver = LibraryResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
fn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
Creates the archived version of this value at the given position and
writes it to the given output. Read more
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourceimpl<'de> Deserialize<'de> for Library
impl<'de> Deserialize<'de> for Library
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<Library, __D> for Archived<Library>where
LibraryId: Archive,
<LibraryId as Archive>::Archived: Deserialize<LibraryId, __D>,
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
LibraryType: Archive,
<LibraryType as Archive>::Archived: Deserialize<LibraryType, __D>,
VecPathBuf: ArchiveWith<Vec<PathBuf>> + DeserializeWith<<VecPathBuf as ArchiveWith<Vec<PathBuf>>>::Archived, Vec<PathBuf>, __D>,
u32: Archive,
<u32 as Archive>::Archived: Deserialize<u32, __D>,
OptionDateTime: ArchiveWith<Option<DateTime<Utc>>> + DeserializeWith<<OptionDateTime as ArchiveWith<Option<DateTime<Utc>>>>::Archived, Option<DateTime<Utc>>, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
MovieReferenceBatchSize: Archive,
<MovieReferenceBatchSize as Archive>::Archived: Deserialize<MovieReferenceBatchSize, __D>,
DateTimeWrapper: ArchiveWith<DateTime<Utc>> + DeserializeWith<<DateTimeWrapper as ArchiveWith<DateTime<Utc>>>::Archived, DateTime<Utc>, __D>,
Option<Vec<Media>>: Archive,
<Option<Vec<Media>> as Archive>::Archived: Deserialize<Option<Vec<Media>>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<Library, __D> for Archived<Library>where
LibraryId: Archive,
<LibraryId as Archive>::Archived: Deserialize<LibraryId, __D>,
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
LibraryType: Archive,
<LibraryType as Archive>::Archived: Deserialize<LibraryType, __D>,
VecPathBuf: ArchiveWith<Vec<PathBuf>> + DeserializeWith<<VecPathBuf as ArchiveWith<Vec<PathBuf>>>::Archived, Vec<PathBuf>, __D>,
u32: Archive,
<u32 as Archive>::Archived: Deserialize<u32, __D>,
OptionDateTime: ArchiveWith<Option<DateTime<Utc>>> + DeserializeWith<<OptionDateTime as ArchiveWith<Option<DateTime<Utc>>>>::Archived, Option<DateTime<Utc>>, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
MovieReferenceBatchSize: Archive,
<MovieReferenceBatchSize as Archive>::Archived: Deserialize<MovieReferenceBatchSize, __D>,
DateTimeWrapper: ArchiveWith<DateTime<Utc>> + DeserializeWith<<DateTimeWrapper as ArchiveWith<DateTime<Utc>>>::Archived, DateTime<Utc>, __D>,
Option<Vec<Media>>: Archive,
<Option<Vec<Media>> as Archive>::Archived: Deserialize<Option<Vec<Media>>, __D>,
Sourceimpl LibraryLike for Library
impl LibraryLike for Library
fn needs_scan(&self) -> bool
fn get_id(&self) -> LibraryId
fn get_name(&self) -> &str
fn get_type(&self) -> LibraryType
fn get_paths(&self) -> Vec<PathBuf>
fn get_scan_interval(&self) -> u32
fn get_last_scan(&self) -> Option<DateTime<Utc>>
fn is_enabled(&self) -> bool
fn is_auto_scan(&self) -> bool
fn is_watch_for_changes(&self) -> bool
fn is_analyze_on_scan(&self) -> bool
fn get_max_retry_attempts(&self) -> u32
fn get_movie_ref_batch_size(&self) -> MovieReferenceBatchSize
fn get_created_at(&self) -> DateTime<Utc>
fn get_updated_at(&self) -> DateTime<Utc>
fn get_media_references_clone(&self) -> Option<Vec<Media>>
Sourceimpl LibraryLikeMut for Library
impl LibraryLikeMut for Library
fn new(name: String, library_type: LibraryType, paths: Vec<PathBuf>) -> Self
fn update_last_scan(&mut self)
fn set_paths(&mut self, paths: Vec<PathBuf>)
fn set_scan_interval(&mut self, interval: u32)
fn set_last_scan(&mut self, last_scan: Option<DateTime<Utc>>)
fn set_auto_scan(&mut self, auto_scan: bool)
fn set_max_retry_attempts(&mut self, max_retry_attempts: u32)
fn set_updated_at(&mut self, updated_at: Option<DateTime<Utc>>)
fn set_media_references(&mut self, media_references: Vec<Media>)
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for Librarywhere
LibraryId: Serialize<__S>,
String: Serialize<__S>,
LibraryType: Serialize<__S>,
VecPathBuf: SerializeWith<Vec<PathBuf>, __S>,
u32: Serialize<__S>,
OptionDateTime: SerializeWith<Option<DateTime<Utc>>, __S>,
bool: Serialize<__S>,
MovieReferenceBatchSize: Serialize<__S>,
DateTimeWrapper: SerializeWith<DateTime<Utc>, __S>,
Option<Vec<Media>>: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for Librarywhere
LibraryId: Serialize<__S>,
String: Serialize<__S>,
LibraryType: Serialize<__S>,
VecPathBuf: SerializeWith<Vec<PathBuf>, __S>,
u32: Serialize<__S>,
OptionDateTime: SerializeWith<Option<DateTime<Utc>>, __S>,
bool: Serialize<__S>,
MovieReferenceBatchSize: Serialize<__S>,
DateTimeWrapper: SerializeWith<DateTime<Utc>, __S>,
Option<Vec<Media>>: Serialize<__S>,