pub struct ScanStageLatencySummary {
pub scan: u64,
pub analyze: u64,
pub index: u64,
}Fields
scan: u64analyze: u64index: u64Trait Implementations
Sourceimpl Archive for ScanStageLatencySummary
impl Archive for ScanStageLatencySummary
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedScanStageLatencySummary
type Archived = ArchivedScanStageLatencySummary
The archived representation of this type. Read more
Sourcetype Resolver = ScanStageLatencySummaryResolver
type Resolver = ScanStageLatencySummaryResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for ScanStageLatencySummary
impl Clone for ScanStageLatencySummary
Sourcefn clone(&self) -> ScanStageLatencySummary
fn clone(&self) -> ScanStageLatencySummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScanStageLatencySummary
impl Debug for ScanStageLatencySummary
Sourceimpl<'de> Deserialize<'de> for ScanStageLatencySummary
impl<'de> Deserialize<'de> for ScanStageLatencySummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ScanStageLatencySummary, __D> for Archived<ScanStageLatencySummary>
impl<__D: Fallible + ?Sized> Deserialize<ScanStageLatencySummary, __D> for Archived<ScanStageLatencySummary>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ScanStageLatencySummary, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ScanStageLatencySummary, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for ScanStageLatencySummary
impl PartialEq for ScanStageLatencySummary
Sourceimpl Serialize for ScanStageLatencySummary
impl Serialize for ScanStageLatencySummary
impl Copy for ScanStageLatencySummary
impl StructuralPartialEq for ScanStageLatencySummary